@@ -33,6 +33,25 @@ fn check_wave(mut node: impl AudioUnit64) {
     }
 }
 
+/// Check that the stereo generator given is rendered identically
+/// via a big block adapter (block processing) and `tick` (single sample processing).
+/// Also check that the generator is reset properly.
+fn check_wave_big(node: Box<dyn AudioUnit64>) {
+    let mut wave = Wave64::with_capacity(2, 44100.0, 44100);
+    wave.resize(44100);
+    let mut big = BigBlockAdapter64::new(node);
+    big.process(44100, &[], wave.channels_mut());
+    big.reset(None);
+    for i in 0..44100 {
+        let (tick_x, tick_y) = big.get_stereo();
+        let process_x = wave.at(0, i);
+        let process_y = wave.at(1, i);
+        let tolerance = 1.0e-9;
+        assert!(tick_x - tolerance <= process_x && tick_x + tolerance >= process_x);
+        assert!(tick_y - tolerance <= process_y && tick_y + tolerance >= process_y);
+    }
+}
+
 /// Check that the stereo filter given is rendered identically
 /// via `process` (block processing) and `tick` (single sample processing).
 /// Also check that the generator is reset properly.
@@ -185,8 +204,12 @@ fn test_basic() {
     check_wave(
         dc((440.0, 880.0)) >> multisplit::<U2, U3>() >> multijoin::<U2, U3>() >> (sine() | sine()),
     );
-    check_wave(dc((110.0, 0.5)) >> pulse() >> delay(0.1) | noise() >> delay(0.01));
-    check_wave(envelope(|t| exp(-t * 10.0)) | lfo(|t| sin(t * 10.0)));
+    check_wave_big(Box::new(
+        dc((110.0, 0.5)) >> pulse() >> delay(0.1) | noise() >> delay(0.01),
+    ));
+    check_wave_big(Box::new(
+        envelope(|t| exp(-t * 10.0)) | lfo(|t| sin(t * 10.0)),
+    ));
 
     let mut sequencer = Sequencer::new(44100.0, 2);
     sequencer.add64(0.1, 0.2, 0.01, 0.02, Box::new(noise() | sine_hz(220.0)));
@@ -196,7 +219,7 @@ fn test_basic() {
     check_wave(sequencer);
 
     check_wave((noise() | envelope(|t| spline_noise(1, t * 10.0))) >> panner());
-    check_wave(noise() >> monitor(0) >> pan(-0.5) | timer(1));
+    check_wave(noise() >> monitor(Meter::Sample, 0) >> pan(-0.5) | timer(1));
     check_wave(tag(0, 5.0) >> lfo2(|t, x| t * x) | tag(1, 1.0));
     check_wave((tag(0, 5.0) | tag(1, 3.0)) >> lfo3(|t, x, y| t * x * y) | tag(1, 1.0));
 
@@ -205,6 +228,10 @@ fn test_basic() {
     check_wave_filter(&input, butterpass_hz(1000.0) | lowpole_hz(100.0));
     check_wave_filter(&input, allpole_delay(0.5) | highpole_hz(500.0));
     check_wave_filter(&input, pluck(60.0, 0.9, 0.8) | pluck(110.0, 0.5, 0.1));
+    check_wave_filter(
+        &input,
+        (pass() | dc((2000.0, 5.0, 0.8))) >> morph() | morph_hz(440.0, 1.0, 0.0),
+    );
 
     // Constants.
     let mut d = constant(1.0);
